package reset;

import java.awt.*;
import java.awt.event.*;
import javax.swing.*;
import java.util.LinkedList;

/**
 * Cette classe est la classe qui gere l'interface de la pile.
 * 
 * @version 1.14
 * @since 5/11/05
 * @author Olivio_Mariano
 */

class StackInterface extends JFrame{
    
    StackPanel stackPanel;
    JButton newStack;
    JButton inStack;
    JButton outStack;
    JButton topofStackDisplay;
    JButton openStack;
    JButton saveStack;
    
    /** Methode pour la gestion de l'interface
     * 
     * @param title
     */
    public StackInterface(String title){
	setTitle(title);
	setJMenuBar(createMenuBar());
	
	JPanel global = new JPanel(new BorderLayout());
	global.add(createToolBar(), BorderLayout.NORTH);

	stackPanel = new StackPanel();
	global.add(stackPanel, BorderLayout.CENTER);

	this.getContentPane().add(global);
	
	WindowListener GUIListener = new WindowAdapter(){
		public void windowClosing(WindowEvent e){
		    System.exit(0);
		}
	    };
	addWindowListener(GUIListener);
    }

    /**
     * Methode qui met en place une barre de menu
     * @return JMenuBar
     */
    private JMenuBar createMenuBar(){
	
	JMenuBar menuBar = new JMenuBar();
	JMenu exitMenu = new JMenu("Quit") ;
	menuBar.add(exitMenu) ;
	JMenuItem exitItem = new JMenuItem("Quit");
	exitItem.addActionListener(new Exit(this));
	exitMenu.add(exitItem);
	return menuBar;
    }
    
    /**
     * Methode qui met en place une barre d'outils avec boutons
     * @return JToolBar
     */
    private JToolBar createToolBar(){

	JToolBar stackTools = new JToolBar();
	
	ImageIcon newButtonIcon = createImageIcon("images/new.jpg");
	ImageIcon saveButtonIcon = createImageIcon("images/save.jpg");
	ImageIcon topButtonIcon = createImageIcon("images/top.jpg");
	ImageIcon addButtonIcon = createImageIcon("images/add.jpg");
	ImageIcon remButtonIcon = createImageIcon("images/rem.jpg");
	ImageIcon openButtonIcon = createImageIcon("images/open.jpg");
	
	newStack = new JButton("New", newButtonIcon);
	newStack.addActionListener(new NewStack(this));

	openStack = new JButton("Open", openButtonIcon);
	openStack.addActionListener(new OpenStack(this));
	openStack.setEnabled(true);
	
	inStack = new JButton("Add", addButtonIcon);
	inStack.addActionListener(new AddtoStack(this));
	inStack.setEnabled(false);
	
	outStack = new JButton("Remove", remButtonIcon);
	outStack.addActionListener(new RmfStack(this));
	outStack.setEnabled(false);
	
	topofStackDisplay = new JButton("Top", topButtonIcon);
	topofStackDisplay.addActionListener(new DisplayTop(this));
	topofStackDisplay.setEnabled(false);

  	saveStack = new JButton("Save", saveButtonIcon);
	saveStack.addActionListener(new SaveStack(this));
	saveStack.setEnabled(true);

	stackTools.add(newStack);
	stackTools.add(openStack);
	stackTools.add(inStack);
	stackTools.add(outStack);
	stackTools.add(topofStackDisplay);
	stackTools.add(saveStack);
	
	newStack.setToolTipText("Create a new stack.");
	openStack.setToolTipText("Load a stack. Please create a new one.");
	inStack.setToolTipText("Add an element in the stack.");
	outStack.setToolTipText("Remove an element from the stack.");
	topofStackDisplay.setToolTipText("Display top of stack.");
	saveStack.setToolTipText("Save into a pile.xml file.");
	
	return stackTools;
    }
	
    /**
     * Methode qui gere les icones a cote des boutons
     * 
     * @return ImeageIcon
     */
   protected static ImageIcon createImageIcon(String path) {
        java.net.URL imgURL = StackInterface.class.getResource(path);
        if (imgURL != null) {
            return new ImageIcon(imgURL);
        } else {
            System.err.println("Couldn't find file: " + path);
            return null;
        }
    }
	
   /**
    * Methode qui gere la fenetre de sortie de l'application.
    *
    */
     public void end(){
	int n = JOptionPane.showConfirmDialog (this, 
					       "Are you sure do you want to quit?",
					       "",
					       JOptionPane.YES_NO_OPTION) ;
	if (n == JOptionPane.YES_OPTION) {
	    System.exit(0) ;
	}
    }
	
}
